@@ -99,35 +99,53 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>DialogMonitorOptions</name>
+    <message>
+        <location filename="MonitorOptions.py" line="87"/>
+        <source>QNetMan (Monitor options)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="MonitorOptions.py" line="88"/>
+        <source>Marker</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="MonitorOptions.py" line="89"/>
+        <source>Timestamp (vertcal line), seconds:</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DialogRecordDataExt</name>
     <message>
-        <location filename="DialogRecordDataExt.py" line="89"/>
+        <location filename="DialogRecordDataExt.py" line="91"/>
         <source>Attention! Data recording will continue to until it is stopped manually, or network interface will be deactivated.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogRecordDataExt.py" line="93"/>
+        <location filename="DialogRecordDataExt.py" line="95"/>
         <source>Data record is disabled</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogRecordDataExt.py" line="110"/>
+        <location filename="DialogRecordDataExt.py" line="112"/>
         <source>MAC address</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogRecordDataExt.py" line="111"/>
+        <location filename="DialogRecordDataExt.py" line="113"/>
         <source>RX bytes/RX packets</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogRecordDataExt.py" line="112"/>
+        <location filename="DialogRecordDataExt.py" line="114"/>
         <source>TX bytes/TX packets</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogRecordDataExt.py" line="113"/>
+        <location filename="DialogRecordDataExt.py" line="115"/>
         <source>Network interface</source>
         <translation type="unfinished"></translation>
     </message>
@@ -260,17 +278,17 @@ record</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="240"/>
+        <location filename="ListSessionsExt.py" line="239"/>
         <source>Warning</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="241"/>
+        <location filename="ListSessionsExt.py" line="240"/>
         <source>Session does not contain data</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="287"/>
+        <location filename="ListSessionsExt.py" line="286"/>
         <source>records</source>
         <translation type="unfinished"></translation>
     </message>
@@ -285,27 +303,27 @@ record</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="325"/>
+        <location filename="ListSessionsExt.py" line="324"/>
         <source>Select a session to calculate the traffic</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="330"/>
+        <location filename="ListSessionsExt.py" line="329"/>
         <source>Sessions:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="333"/>
+        <location filename="ListSessionsExt.py" line="332"/>
         <source>Full traffic:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="331"/>
+        <location filename="ListSessionsExt.py" line="330"/>
         <source>RX bytes:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="332"/>
+        <location filename="ListSessionsExt.py" line="331"/>
         <source>TX bytes:</source>
         <translation type="unfinished"></translation>
     </message>
@@ -323,12 +341,6 @@ record</source>
 sessions</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="MainWindow.py" line="79"/>
-        <source>Monitor of 
-connections</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="MainWindow.py" line="81"/>
         <source>Settings</source>
@@ -341,7 +353,7 @@ connections</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="194"/>
+        <location filename="ViewSession.py" line="232"/>
         <source>Menu</source>
         <translation type="unfinished"></translation>
     </message>
@@ -536,67 +548,67 @@ connections</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="178"/>
+        <location filename="ViewSession.py" line="211"/>
         <source>QNetMan (Sessions)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="179"/>
+        <location filename="ViewSession.py" line="212"/>
         <source>Session start time:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="180"/>
+        <location filename="ViewSession.py" line="213"/>
         <source>Session end time:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="182"/>
+        <location filename="ViewSession.py" line="215"/>
         <source>2000-01-01 00:00:00</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="192"/>
+        <location filename="ViewSession.py" line="225"/>
         <source>RX:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="186"/>
+        <location filename="ViewSession.py" line="219"/>
         <source>0000.00 MB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="193"/>
+        <location filename="ViewSession.py" line="226"/>
         <source>TX:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="187"/>
+        <location filename="ViewSession.py" line="220"/>
         <source>Session full time:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="188"/>
+        <location filename="ViewSession.py" line="221"/>
         <source>00 h; 00 m; 00 s</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="189"/>
+        <location filename="ViewSession.py" line="222"/>
         <source>Full session traffic :</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="190"/>
+        <location filename="ViewSession.py" line="223"/>
         <source>000000 MB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="191"/>
+        <location filename="ViewSession.py" line="224"/>
         <source>Rendering...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="195"/>
+        <location filename="ViewSession.py" line="233"/>
         <source>Remove session</source>
         <translation type="unfinished"></translation>
     </message>
@@ -684,9 +696,20 @@ p, li { white-space: pre-wrap; }
         <source>QNetMan (Settings)</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="MainWindow.py" line="79"/>
+        <source>Monitor 
+connections</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="ViewSession.py" line="231"/>
+        <source>000 kB/s</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="WinAbout.py" line="89"/>
-        <source>0.3.0</source>
+        <source>0.4.0</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -750,67 +773,67 @@ Start daemons now ?</source>
 <context>
     <name>ViewCurrentSession</name>
     <message>
-        <location filename="ViewCurrentSession.py" line="182"/>
+        <location filename="ViewCurrentSession.py" line="162"/>
         <source>QNetMan (Monitor)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="195"/>
+        <location filename="ViewCurrentSession.py" line="175"/>
         <source>RX:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="185"/>
+        <location filename="ViewCurrentSession.py" line="165"/>
         <source>000.00 MB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="196"/>
+        <location filename="ViewCurrentSession.py" line="176"/>
         <source>TX:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="188"/>
+        <location filename="ViewCurrentSession.py" line="168"/>
         <source>V</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="190"/>
+        <location filename="ViewCurrentSession.py" line="170"/>
         <source>000.00 MB/s</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="191"/>
+        <location filename="ViewCurrentSession.py" line="171"/>
         <source>rx</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="192"/>
+        <location filename="ViewCurrentSession.py" line="172"/>
         <source>tx</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="193"/>
+        <location filename="ViewCurrentSession.py" line="173"/>
         <source>Interval:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="194"/>
+        <location filename="ViewCurrentSession.py" line="174"/>
         <source>2 sec</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="197"/>
+        <location filename="ViewCurrentSession.py" line="177"/>
         <source>Options</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="198"/>
+        <location filename="ViewCurrentSession.py" line="178"/>
         <source>Refresh interval</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="199"/>
+        <location filename="ViewCurrentSession.py" line="179"/>
         <source>Network interface</source>
         <translation type="unfinished"></translation>
     </message>
@@ -818,22 +841,22 @@ Start daemons now ?</source>
 <context>
     <name>ViewCurrentSessionExt</name>
     <message>
-        <location filename="ViewCurrentSessionExt.py" line="357"/>
+        <location filename="ViewCurrentSessionExt.py" line="486"/>
         <source>Refresh interval:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSessionExt.py" line="358"/>
+        <location filename="ViewCurrentSessionExt.py" line="487"/>
         <source>sec</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSessionExt.py" line="423"/>
+        <location filename="ViewCurrentSessionExt.py" line="617"/>
         <source>Selected network interface:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSessionExt.py" line="466"/>
+        <location filename="ViewCurrentSessionExt.py" line="660"/>
         <source>Recording...</source>
         <translation type="unfinished"></translation>
     </message>
@@ -841,17 +864,17 @@ Start daemons now ?</source>
 <context>
     <name>ViewSessionExt</name>
     <message>
-        <location filename="ViewSessionExt.py" line="135"/>
+        <location filename="ViewSessionExt.py" line="148"/>
         <source>h</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSessionExt.py" line="136"/>
+        <location filename="ViewSessionExt.py" line="149"/>
         <source>m</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSessionExt.py" line="137"/>
+        <location filename="ViewSessionExt.py" line="150"/>
         <source>s</source>
         <translation type="unfinished"></translation>
     </message>
@@ -859,35 +882,35 @@ Start daemons now ?</source>
 <context>
     <name>WinAboutExt</name>
     <message>
-        <location filename="WinAboutExt.py" line="128"/>
+        <location filename="WinAboutExt.py" line="131"/>
         <source>Thanks:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinAboutExt.py" line="129"/>
-        <source>Sinichkin Vladimir - for translation</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="WinAboutExt.py" line="141"/>
+        <location filename="WinAboutExt.py" line="144"/>
         <source>Licence:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinAboutExt.py" line="142"/>
+        <location filename="WinAboutExt.py" line="145"/>
         <source>GPL v2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinAboutExt.py" line="130"/>
+        <location filename="WinAboutExt.py" line="133"/>
         <source>Used icon set &quot;Crystal-clear&quot; by Everaldo Coelho</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinAboutExt.py" line="119"/>
+        <location filename="WinAboutExt.py" line="122"/>
         <source>Qt-based network manager which allows to monitor your network traffic. It is possible to record network sessions information for different connections and provide the information in graphical view.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="WinAboutExt.py" line="132"/>
+        <source>Vladimir Sinichkin - for translation</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>WinNetStat</name>
