@@ -8,16 +8,34 @@ import ViewCurrentSession
 import DialogRefreshInterval
 import DialogNetworkIface
 import DialogRecordDataExt
+import MonitorOptions
 import StatistData
 
 from collections import deque
 
 import dbus
 
+import QNMSettings
+
 from gettraff import GetTraff
 from mydb import MyDB
 import myconfig
 
+import sys
+
+class MyGraphicsScene( QtGui.QGraphicsScene ):
+	mousePressed = QtCore.Signal(int,int)
+	def __init__(self, parent = None):
+		QtGui.QGraphicsScene.__init__(self, parent)
+
+	def mousePressEvent( self, eventGrSc ):
+		p = eventGrSc.scenePos()
+		self.mousePressed.emit( p.x(), p.y() )
+
+		QtGui.QGraphicsScene.mousePressEvent( self, eventGrSc )
+
+	
+
 
 class ViewCurrentSessionExt( QtGui.QMainWindow ):
 	def __init__(self, parent, mydbus, iface='gprs0'):
@@ -32,6 +50,8 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 			pass
 			#print "ViewCurrentSessionExt::__init__(): Exception setAttribute(): ",e
 
+		self.qset = QNMSettings.QNMSettings( myconfig.file_setting, self )
+
 		self.frm = ViewCurrentSession.Ui_ViewCurrentSession()
 		self.frm.setupUi( self )
 		self.actionForm()
@@ -88,12 +108,48 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 
 		self.X=0
 		self.scene = QtGui.QGraphicsScene()
+		##XXX##self.scene = MyGraphicsScene( self )
+		##XXX##self.scene.mousePressed.connect( self.sceneMousePress )
+
 		self.frm.graphicsView.setScene(self.scene)
 		self.frm.graphicsView.setSceneRect(0, 0, self.lengthX, self.lengthY)
 		self.frm.graphicsView.centerOn(0,0)
 
-		self.showRX = True
-		self.showTX = True
+		#параметры для маркера
+		self.itemLine = None
+		self.itemBox = None
+		self.itemText = None
+		self.x_marker = 0
+		self.y_marker = 0
+		self.maxScaleY = 0
+
+		self.pen_marker = QtGui.QPen( QtGui.QColor(170,170,170) )
+		self.pen_marker.setWidth(1)
+		self.pen_marker.setStyle( QtCore.Qt.DashDotLine )
+	
+		self.font_marker = QtGui.QFont()
+		self.font_marker.setPointSize(9)
+	
+		self.bx_marker = QtGui.QPen( QtGui.QColor(110,110,110) )
+		self.bx_marker.setWidth(15)
+		self.bx_marker.setCapStyle( QtCore.Qt.RoundCap )
+			
+
+		# *** инициализация настроек *** #
+		#тип рисуемого графика
+		# 0 - статичтический вид
+		# 1 - временной вид
+		self.typeGraph = self.qset.typeGraph()
+
+		#Отображаем ли линейку
+		self.showMarker = self.qset.isShowRuler()
+
+		self.showRX = self.qset.isShowRX()
+		self.showTX = self.qset.isShowTX()
+
+		self.timestamp = self.qset.timestamp()
+
+		# *** * *** #
 
 		#ширина линии графика (пиксель)
 		self.pxLenGraph = 5
@@ -102,12 +158,6 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 
 		self.dbusWaitDisplayOff()
 	
-#	def startTimer(self):
-#		self.timer.start( self.timeout * 1000 )
-#	
-#	def startTimer(self):
-#		self.timer.stop( )
-
 	
 	def drawSystemCoord(self):
 		pen = QtGui.QPen( QtGui.QColor(100,100,100) )
@@ -127,12 +177,15 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 		font.setPointSize(9)
 
 		x = 0
+		ts = 0
 		while x < self.lengthX:
 			self.scene.addLine( x+self.shiftX, 0, x+self.shiftX, self.lengthY - self.shiftY, pen )
-			x += (30/self.timeout)*self.pxLenGraph # 1 расстояние между вертикальными линиями сетки - 30 сек
+			x += (self.timestamp/self.timeout)*self.pxLenGraph # 1 расстояние между вертикальными линиями сетки - 30 сек
+			ts += self.timestamp
+			self.scene.addText( "%s"%ts, font ).setPos( x-10, self.lengthY-15 )
 			
 		
-		partY = 4
+		partY = 4.0
 		stepLineY = self.Ly/(partY) #шаг горизонтально (по оси Y) линии сетки
 		currY = self.Ly
 		it = 0
@@ -140,8 +193,10 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 		while it < (partY+1):
 			self.scene.addLine( self.shiftX, self.Ly-currY, self.lengthX, self.Ly-currY, pen )
 			txt = ""
+			if( maxScaleY > 1048576 ):
+				txt = "%s MB/s"%( it*myMaxScaleY/1048576.0 ) 
 			if( maxScaleY > 1024 ):
-				txt = "%s kB/s"%( it*myMaxScaleY/1024 ) 
+				txt = "%s kB/s"%( it*myMaxScaleY/1024.0 ) 
 			else:
 				txt = "%s B/s"%( it*myMaxScaleY ) 
 			self.scene.addText( txt, font ).setPos( self.shiftX, currY )
@@ -158,15 +213,12 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 		self.colorTX = QtGui.QColor( rgbTX )
 		self.frm.lblColorRX.setStyleSheet("background-color: %s;"%(rgbRX) )
 		self.frm.lblColorTX.setStyleSheet("background-color: %s;"%(rgbTX) )
-
-		penRX = QtGui.QPen( self.colorRX )
-		penRX.setWidth( self.pxLenGraph )
-		penTX = QtGui.QPen( self.colorTX )
-		penTX.setWidth( self.pxLenGraph )
+		#print >> sys.stderr, "style ok"
 
 		dx = self.shiftX + self.pxLenGraph/2
 
 		self.scene.clear()
+		#print >> sys.stderr, "clear ok"
 
 		#получаем результат - переводим его в скорость: байт/сек
 		rx,tx,ok = self.getTraffData( self.iface )
@@ -184,6 +236,7 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 				self.frm.widgetRecordStatus.hide()
 		rx = (rx*1.0)/self.timeout
 		tx = (tx*1.0)/self.timeout 
+		#print >> sys.stderr, "getTraffData ok"
 
 		# проталкиваем очередное полученное значение в очередь
 		if( (self.X+dx) > self.lengthX ):
@@ -198,6 +251,7 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 			self.X = self.lengthX
 		self.viewPointOnGraphRX.append( rx )
 		self.viewPointOnGraphTX.append( tx )
+		#print >> sys.stderr, "popleft ok"
 
 		# берем максимальное значение из каждой очереди если они рисуются обе,
 		# иначе, макс. занчение графика, очередь которого будет отображаться
@@ -220,29 +274,65 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 				break
 			m += 1
 		maxScaleY = 2**m
-
+		
 		#отрисовка значений, заполняющих каждую деку входящего/исходящего трафика
 		x=0
 		j=0
-		while j < len(self.viewPointOnGraphRX):
+		if self.typeGraph == 0:
+			penRX = QtGui.QPen( self.colorRX )
+			penRX.setWidth( self.pxLenGraph )
+			penTX = QtGui.QPen( self.colorTX )
+			penTX.setWidth( self.pxLenGraph )
 
-			if self.showRX:
-				r = (self.Ly*(1.0 / maxScaleY))*self.viewPointOnGraphRX[j]
-				self.scene.addLine( x+dx, self.Ly, x+dx, self.Ly-r, penRX )
+			while j < len(self.viewPointOnGraphRX):
+	
+				if self.showRX:
+					r = (self.Ly*(1.0 / maxScaleY))*self.viewPointOnGraphRX[j]
+					self.scene.addLine( x+dx, self.Ly, x+dx, self.Ly-r, penRX )
 
-			if self.showTX:
-				t = (self.Ly*(1.0 / maxScaleY))*self.viewPointOnGraphTX[j]
-				self.scene.addLine( x+dx, self.Ly, x+dx, self.Ly-t, penTX )
+				if self.showTX:
+					t = (self.Ly*(1.0 / maxScaleY))*self.viewPointOnGraphTX[j]
+					self.scene.addLine( x+dx, self.Ly, x+dx, self.Ly-t, penTX )
+	
+				x += self.pxLenGraph
+				j += 1
+		elif self.typeGraph == 1:
+			penRX = QtGui.QPen( self.colorRX )
+			penRX.setWidth( 2 )
+			penTX = QtGui.QPen( self.colorTX )
+			penTX.setWidth( 2 )
+
+			while j < (len(self.viewPointOnGraphRX)-1):
+	
+				if self.showRX:
+					r1 = (self.Ly*(1.0 / maxScaleY))*self.viewPointOnGraphRX[j+1]
+					r0 = (self.Ly*(1.0 / maxScaleY))*self.viewPointOnGraphRX[j]
+					self.scene.addLine( x+dx, self.Ly-r0, x+dx+self.pxLenGraph, self.Ly-r1, penRX )
+
+				if self.showTX:
+					t1 = (self.Ly*(1.0 / maxScaleY))*self.viewPointOnGraphTX[j+1]
+					t0 = (self.Ly*(1.0 / maxScaleY))*self.viewPointOnGraphTX[j]
+					self.scene.addLine( x+dx, self.Ly-t0, x+dx+self.pxLenGraph, self.Ly-t1, penTX )
+	
+				x += self.pxLenGraph
+				j += 1
 
-			x += self.pxLenGraph
-			j += 1
 		self.X = self.X + self.pxLenGraph
+		#print >> sys.stderr, "draw gr ok"
 
 		#отрисовка сетки и системы координат
 		self.drawSystemCoord()
 		self.drawGrid(maxScaleY)
 		
+		#отрисовка линейки, если используется
+		self.maxScaleY = maxScaleY
+		#print >> sys.stderr, "drawMarkerScene"
+		self.drawMarkerScene()
+		#print >> sys.stderr, "drawMarkerScene ok"
+
+		
 		self.scene.update()
+		#print >> sys.stderr, "update ok"
 
 		#счетчик трафика
 		if (self.rx1/1024) > 1048576:
@@ -279,6 +369,9 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 			self.frm.lblVoutValue.setText( "%.2f kB/s"%(tx/1024.0) )
 		else:
 			self.frm.lblVoutValue.setText( "%.2f B/s"%(tx) )
+		#print >> sys.stderr, "setText ok"
+
+		#print >> sys.stderr, ""
 
 	
 	def getTraffData(self, iface):
@@ -299,30 +392,79 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 		return (rx, tx, okread)
 
 	def actionForm(self):
-		self.frm.pBshowRX.clicked.connect( self.changeShowRX )
-		self.frm.pBshowTX.clicked.connect( self.changeShowTX )
 		self.frm.pBrec.clicked.connect( self.dlgRecordData )
 		self.frm.pbRecordStatus.clicked.connect( self.notifyRecNow )
 
 		QtCore.QObject.connect(self.frm.actionRefreshInterval, QtCore.SIGNAL("triggered()"), self.dialogRefreshInterval)
 		QtCore.QObject.connect(self.frm.actionIface, QtCore.SIGNAL("triggered()"), self.dialogIfaceSelect)
 		
-		#self.dlgRec = QtGui.QDialog()
-		#self.ui_dlgRec = DialogRecordDataExt.DialogRecordManagerExt( self.dlgRec, self.mydbus )
-		#self.ui_dlgRec.stateRecordChange.connect( self.stateRecordChangeHere )
+		# кнопка вызова диалога "Настройки монитора" и вся соответствующая ей хрень
+		self.frm.pBopt.clicked.connect( self.dialogMonitorOptions )
 
-	def changeShowRX(self):
-		if self.showRX:
-			self.showRX = False
+		self.dlgMO = QtGui.QDialog()
+		self.ui_dlgMO = MonitorOptions.Ui_DialogMonitorOptions( )
+		self.ui_dlgMO.setupUi( self.dlgMO )
+
+		self.ui_dlgMO.bGrGraphType.buttonPressed.connect( self.changeGrT )
+		##XXX##self.ui_dlgMO.cbRuler.stateChanged.connect( self.changeRuler )
+		self.ui_dlgMO.pbTraffRX.toggled.connect( self.changeShowRX )
+		self.ui_dlgMO.pbTraffTX.toggled.connect( self.changeShowTX )
+		self.ui_dlgMO.sbTimestamp.valueChanged.connect( self.changeTimestamp )
+
+
+	def changeShowRX(self, state):
+		self.showRX = state
+		self.qset.showRX( state )
+
+	def changeShowTX(self, state):
+		self.showTX = state
+		self.qset.showTX( state )
+
+	
+	#-----------------#
+	#вызывается, когда кликают на сцену
+	def sceneMousePress(self, x, y):
+		self.x_marker = x
+		self.y_marker = y
+
+		if self.itemLine != None:
+			self.itemLine.hide()
+			self.itemLine = None
+		if self.itemBox != None:
+			self.itemBox.hide()
+			self.itemBox = None
+		if self.itemText != None:
+			self.itemText.hide()
+			self.itemText = None
+		self.drawMarkerScene()
+	
+
+	def drawMarkerScene(self):
+		x = self.x_marker
+		y = self.y_marker
+
+		if self.showMarker:
+			val = (self.maxScaleY - (1.0*y / self.Ly )*self.maxScaleY)
+			if val < 0:
+				val = 0
+			if val > 1048576:
+				val = "%.2f MB/s"%( val/1048576.0 )
+			elif val > 1024:
+				val = "%.2f kB/s"%(val/1024.0)
+			else:
+				val = "%.2f B/s"%(val)
+			self.itemLine = self.scene.addLine( 0, y, self.Lx, y, self.pen_marker )
+			dy = 10
+			if y < 20:
+				dy = -15
+			self.itemBox = self.scene.addLine( x+15, y-dy, x+80, y-dy, self.bx_marker )
+			self.itemText = self.scene.addText( "%s"%val, self.font_marker )
+			self.itemText.setPos( x+15, (y-(dy+12)) )
 		else:
-			self.showRX = True
-
-	def changeShowTX(self):
-		if self.showTX:
-			self.showTX = False
-		else:
-			self.showTX = True
-
+			self.itemLine = None
+			self.itemBox = None
+			self.itemText = None
+	
 	#-----------------#
 	def dialogRefreshInterval(self):
 		self.dlg = QtGui.QDialog( )
@@ -358,6 +500,70 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 		txt2 = QtGui.QApplication.translate("ViewCurrentSessionExt", "sec", None, QtGui.QApplication.UnicodeUTF8)
 		self.noti.notify( "%s %s %s"%(txt1, self.timeout, txt2) )
 
+	#-----------------#
+	def dialogMonitorOptions(self):
+		#смена вида графика
+		if self.qset.isTypeGrapStat():
+			self.ui_dlgMO.rbTypeStat.setChecked( True )
+			self.typeGraph = 0
+		else:
+			self.ui_dlgMO.rbTypeTime.setChecked( True )
+			self.typeGraph = 1
+
+		#включение линейки
+		if self.qset.isShowRuler():
+			##XXX##self.ui_dlgMO.cbRuler.setCheckState( QtCore.Qt.Checked )
+			self.showMarker = True
+			self.qset.showRuler( True )
+		else:
+			##XXX##self.ui_dlgMO.cbRuler.setCheckState( QtCore.Qt.Unchecked )
+			self.showMarker = False
+			self.qset.showRuler( False )
+
+		#Отображение графиков
+		if self.showRX:
+			self.ui_dlgMO.pbTraffRX.setChecked( True )
+			self.qset.showRX( True )
+		else:
+			self.ui_dlgMO.pbTraffRX.setChecked( False )
+			self.qset.showRX( False )
+		
+		if self.showTX:
+			self.ui_dlgMO.pbTraffTX.setChecked( True )
+			self.qset.showTX( True )
+		else:
+			self.ui_dlgMO.pbTraffTX.setChecked( False )
+			self.qset.showTX( False )
+
+		#Отображение значений временной метки
+		self.ui_dlgMO.sbTimestamp.setValue( self.qset.timestamp() )
+
+		self.dlgMO.show()
+		self.dlgMO.exec_()
+
+	#изменение вида графика
+	def changeGrT(self, button):
+		if button == self.ui_dlgMO.rbTypeTime:
+			self.qset.setTypeGraphTime()
+			self.typeGraph = 1
+		elif button == self.ui_dlgMO.rbTypeStat:
+			self.qset.setTypeGraphStat()
+			self.typeGraph = 0
+	
+	#изменение видимости линейки
+	def changeRuler(self, state ):
+		if state == QtCore.Qt.Checked:
+			self.showMarker = True
+			self.qset.showRuler( True )
+		else:
+			self.showMarker = False
+			self.qset.showRuler( False )
+
+	#изменения значений временных меток
+	def changeTimestamp( self, value ):
+		self.qset.setTimestamp( "%s"%value )
+		self.timestamp = (int)(value)
+
 	#-----------------#
 	def dialogIfaceSelect(self):
 		self.dlgIface = QtGui.QDialog()
