@@ -27,6 +27,9 @@ class WinAboutExt( QtGui.QMainWindow ):
 		self.createSubSlidingWidgets()
 		self.createSlidingStackedWidget()
 
+		#XXX# Версия программы #XXX#
+		self.ui.lblVersionVal.setText("0.4.0")
+
 		self.actionForm()
 
 	def actionForm(self):
@@ -126,7 +129,7 @@ class WinAboutExt( QtGui.QMainWindow ):
 
 	def setContentP2(self):
 		txt1 = QtGui.QApplication.translate("WinAboutExt", "Thanks:", None, QtGui.QApplication.UnicodeUTF8)
-		txt2 = QtGui.QApplication.translate("WinAboutExt", "Sinichkin Vladimir - for translation", None, QtGui.QApplication.UnicodeUTF8)
+		txt2 = QtGui.QApplication.translate("WinAboutExt", "Vladimir Sinichkin - for translation", None, QtGui.QApplication.UnicodeUTF8)
 		txt3 = QtGui.QApplication.translate("WinAboutExt", "Used icon set \"Crystal-clear\" by Everaldo Coelho", None, QtGui.QApplication.UnicodeUTF8)
 		str  = "<html>"
 		str += "<div style='font-size: 14pt;'>"
